@@ -96,7 +96,7 @@
 #endif
 
 #ifndef USE_MINIZIP
-/* #undef USE_MINIZIP */
+#define USE_MINIZIP
 #endif
 
 #ifndef USE_PNG
